#
# Conditional build:
%bcond_without	tests		# build without tests

%define		php_name	php%{?php_suffix}
%define		modname		imagick
%define		status		stable
%define		libversion	%(pkg-config --modversion MagickCore || echo ERROR)
Summary:	%{modname} - PHP wrapper to the Image Magick Library
Summary(pl.UTF-8):	%{modname} - PHP-owy wrapper do biblioteki Image Magick
Name:		%{php_name}-pecl-%{modname}
Version:	3.4.3
Release:	6
License:	PHP 3.01
Group:		Development/Languages/PHP
Source0:	https://pecl.php.net/get/%{modname}-%{version}.tgz
# Source0-md5:	d0ee25c007cd2a28cefccc0b9ee63a28
Patch0:		skip_version_check.patch
URL:		https://pecl.php.net/package/imagick
BuildRequires:	%{php_name}-devel >= 4:5.3
BuildRequires:	ImageMagick-devel >= 1:6.2.4.0
BuildRequires:	pkgconfig
BuildRequires:	re2c
BuildRequires:	rpmbuild(macros) >= 1.650
%if %{with tests}
BuildRequires:	%{php_name}-cli
BuildRequires:	%{php_name}-pcre
BuildRequires:	%{php_name}-spl
BuildRequires:	ImageMagick-coder-jpeg
BuildRequires:	ImageMagick-coder-png
BuildRequires:	ImageMagick-coder-tiff
%endif
%{?requires_php_extension}
Requires(triggerpostun):	sed >= 4.0
Requires:	%{php_name}-spl
Suggests:	ImageMagick-coder-jpeg
Suggests:	ImageMagick-coder-png
Suggests:	ImageMagick-coder-tiff
Provides:	php(imagick) = %{version}
Provides:	php(lib-imagick) = %{libversion}
Obsoletes:	php-pecl-imagick < 3.1.2-2
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
ImageMagick is a robust collection of tools and libraries to read,
write, and manipulate an image in many image formats (over 68 major
formats) including popular formats like TIFF, JPEG, PNG, PDF, PhotoCD,
and GIF. With ImageMagick you can create images dynamically, making it
suitable for Web applications. You can also resize, rotate, sharpen,
color reduce, or add special effects to an image and save your
completed work in the same or differing image format.

In PECL status of this package is: %{status}.

%description -l pl.UTF-8
ImageMagick to duży zestaw narzędzi i bibliotek do odczytu, zapisu i
modyfikowania obrazków w wielu formatach (ponad 68 głównych), w tym
popularnych, takich jak TIFF, JPEG, PNG, PDF, PhotoCD i GIF. Za pomocą
ImageMagick można dynamicznie tworzyć obrazki, co jest przydatne w
aplikacjach WWW. Można je także przeskalowywać, obracać, wyostrzać,
zmniejszać ilość kolorów - w tym samym lub innym formacie.

To rozszerzenie ma w PECL status: %{status}.

%prep
%setup -qc
mv %{modname}-%{version}/* .
%patch0 -p1

xfail() {
	t=$1
	cat >> $t <<-EOF

	--XFAIL--
	Skip
	EOF
}
Test() {
	nf=$(eval echo \$$#)
	t=$nf; t=${t#\[}; t=${t%\]}
	xfail $t
}
# skip failing tests
Test Imagick, annotateImage [tests/034_Imagick_annotateImage_basic.phpt]
Test Imagick, setRegistry and getRegistry [tests/150_Imagick_setregistry.phpt]
Test ImagickDraw, composite [tests/177_ImagickDraw_composite_basic.phpt]
Test ImagickDraw, setFontSize [tests/206_ImagickDraw_setFontSize_basic.phpt]
Test ImagickDraw, setFontFamily [tests/207_ImagickDraw_setFontFamily_basic.phpt]
Test ImagickDraw, setFontStretch [tests/208_ImagickDraw_setFontStretch_basic.phpt]
Test ImagickDraw, setFontWeight [tests/209_ImagickDraw_setFontWeight_basic.phpt]
Test ImagickDraw, setFontStyle [tests/210_ImagickDraw_setFontStyle_basic.phpt]
Test ImagickDraw, setGravity [tests/212_ImagickDraw_setGravity_basic.phpt]
Test ImagickDraw, setTextAlignment [tests/222_ImagickDraw_setTextAlignment_basic.phpt]
Test ImagickDraw, setTextAntialias [tests/223_ImagickDraw_setTextAntialias_basic.phpt]
Test ImagickDraw, setTextUnderColor [tests/224_ImagickDraw_setTextUnderColor_basic.phpt]
Test ImagickDraw, setTextDecoration [tests/225_ImagickDraw_setTextDecoration_basic.phpt]
Test Tutorial, psychedelicFont [tests/241_Tutorial_psychedelicFont_basic.phpt]
Test Tutorial, svgExample [tests/243_Tutorial_svgExample_basic.phpt]
Test Tutorial, psychedelicFontGif [tests/244_Tutorial_psychedelicFontGif_basic.phpt]
Test Imagick, Imagick::exportImagePixels [tests/256_Imagick_exportImagePixels_basic.phpt]
Test ImagickDraw, getTextDirection [tests/264_ImagickDraw_getTextDirection_basic.phpt]
Test ImagickDraw, getFontResolution [tests/266_ImagickDraw_getFontResolution_basic.phpt]
%ifarch x32
# Fail on 7.0
Test Imagick, quantizeImage [tests/101_Imagick_quantizeImage_basic.phpt]
Test Imagick, uniqueImageColors [tests/163_Imagick_uniqueImageColors_basic.phpt]
Test Tutorial, deconstructGif [tests/237_Tutorial_deconstructGif_basic.phpt]
Test ImagickPixelIterator, setIteratorRow [tests/251_ImagickPixelIterator_setIteratorRow_basic.phpt]
%endif

%build
phpize
%configure \
	php_cv_cc_dashr=false

%{__make} \
	CFLAGS_CLEAN="%{rpmcflags}"

%if %{with tests}
%{__php} -n -q \
	-d extension_dir=modules \
	-d extension=%{php_extensiondir}/pcre.so \
	-d extension=%{php_extensiondir}/spl.so \
	-d extension=%{modname}.so \
	-m > modules.log
grep %{modname} modules.log

export NO_INTERACTION=1 REPORT_EXIT_STATUS=1 MALLOC_CHECK_=2
%{__make} test \
	PHP_EXECUTABLE=%{__php} \
	PHP_TEST_SHARED_SYSTEM_EXTENSIONS="pcre spl" \
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{php_sysconfdir}/conf.d,%{php_extensiondir},%{_examplesdir}/%{name}-%{version}}
install -p modules/%{modname}.so $RPM_BUILD_ROOT%{php_extensiondir}
cat <<'EOF' > $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d/%{modname}.ini
; Enable %{modname} extension module
extension=%{modname}.so
EOF
cp -a examples/* $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post
%php_webserver_restart

%postun
if [ "$1" = 0 ]; then
	%php_webserver_restart
fi

%triggerpostun -- %{name} < 0.9.11-2.1
%{__sed} -i -e '/^extension[[:space:]]*=[[:space:]]*%{modname}\.so/d' %{php_sysconfdir}/php.ini

%files
%defattr(644,root,root,755)
%doc CREDITS
%config(noreplace) %verify(not md5 mtime size) %{php_sysconfdir}/conf.d/%{modname}.ini
%attr(755,root,root) %{php_extensiondir}/%{modname}.so
%{_examplesdir}/%{name}-%{version}
%changelog
* Wed Oct 31 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/php-pecl-imagick.git;a=log;h=auto/th/php-pecl-imagick-3.4.3-6

* Wed Oct 31 2018 Elan Ruusamäe <glen@pld-linux.org> 4f00096
- provide imagick library version built against

* Tue May 22 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> ce99de1
- release 5 (by relup.sh)

* Tue Dec 26 2017 Jan Rękorajski <baggins@pld-linux.org> 5f8da6b
- disable bad test (imagemagick stringregistry will not throw)
- rel 4

* Mon Sep 04 2017 Elan Ruusamäe <glen@delfi.ee> 142a9e6
- ImageMagick-7.0.7.0-1 rebuild
- release 3 (by relup.sh)

* Wed May 03 2017 Elan Ruusamäe <glen@delfi.ee> c2bedcf
- ImageMagick-7.0.5-5 rebuild
- release 2 (by relup.sh)

* Mon Apr 10 2017 Elan Ruusamäe <glen@delfi.ee> 2f0fc69
- up to 3.4.3

* Tue Dec 27 2016 Jan Rękorajski <baggins@pld-linux.org> 2a03fe3
- rebuild with ImageMagick 7.0.4.0
- rel 2

* Sun Dec 25 2016 Jan Rękorajski <baggins@pld-linux.org> 59b4873
- update to 3.4.3rc1 to fix most regressions wrt ImageMagick 7

* Wed Nov 02 2016 Elan Ruusamäe <glen@delfi.ee> b49484d
- use xfail; skip more tests on x32

* Wed Nov 02 2016 Elan Ruusamäe <glen@delfi.ee> 58592d8
- BR update

* Wed Nov 02 2016 Elan Ruusamäe <glen@delfi.ee> 501a42f
- i686 spl requires pcre

* Wed Nov 02 2016 Elan Ruusamäe <glen@delfi.ee> f5c1a0f
- skip failing tests

* Wed Nov 02 2016 Elan Ruusamäe <glen@delfi.ee> 4dc1d66
- test deps

* Wed Nov 02 2016 Elan Ruusamäe <glen@delfi.ee> a70f854
- run tests

* Wed Nov 02 2016 Elan Ruusamäe <glen@delfi.ee> b65e848
- requires spl

* Tue Aug 30 2016 Elan Ruusamäe <glen@delfi.ee> 4baa9e0
- skip stupid version check

* Thu May 19 2016 Elan Ruusamäe <glen@delfi.ee> 4c078d1
- no longer compiles with php 5.2

* Thu May 19 2016 Elan Ruusamäe <glen@delfi.ee> a0d4704
- up to 3.4.2; php-7 support

* Fri Mar 20 2015 Elan Ruusamäe <glen@delfi.ee> 22ad31f
- release 5 (by relup.sh)

* Thu May 22 2014 Elan Ruusamäe <glen@delfi.ee> ee3b6a5
- versioned provides

